# SPHIRE-crYOLO

Deep learning particle picking procedure based YOLO.
Please see [our website](http://sphire.mpg.de/wiki/doku.php?id=downloads:cryolo_1) for more information.

## License
The license information can be found here:

[EULA license of crYOLO](http://sphire.mpg.de/wiki/doku.php?id=cryolo_license)

## Paper
If you use crYOLO, please cite

Wagner, T. et al. SPHIRE-crYOLO is a fast and accurate fully automated particle picker for cryo-EM. Communications Biology 2, (2019).
 
 https://doi.org/10.1038/s42003-019-0437-z